# Superset dashboard config

## Description

This directory provides yaml files for Superset dashboard configuration.
The files inside are not supposed to be edited manually for lest of compatibility breaks.
Placeholders inside the files will be filled automatically when you use the 
`chatsky.stats` CLI command to generate a configuration archive.

Use `chatsky.stats -h` for more info.